BasesDecomposition
==================

.. currentmodule:: pykeen.nn.message_passing

.. autoclass:: BasesDecomposition
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BasesDecomposition.base_weights
      ~BasesDecomposition.bases

   .. rubric:: Methods Summary

   .. autosummary::

      ~BasesDecomposition.forward_horizontally_stacked
      ~BasesDecomposition.forward_vertically_stacked
      ~BasesDecomposition.iter_extra_repr
      ~BasesDecomposition.reset_parameters

   .. rubric:: Attributes Documentation

   .. autoattribute:: base_weights
   .. autoattribute:: bases

   .. rubric:: Methods Documentation

   .. automethod:: forward_horizontally_stacked
   .. automethod:: forward_vertically_stacked
   .. automethod:: iter_extra_repr
   .. automethod:: reset_parameters
